@@ -390,6 +390,10 @@
 #include "token_info-5.34.0.h"
 #elif PERL_VERSION == 34 && PERL_SUBVERSION == 1
 #include "token_info-5.34.0.h"
+#elif PERL_VERSION == 34 && PERL_SUBVERSION == 2
+#include "token_info-5.34.0.h"
+#elif PERL_VERSION == 34 && PERL_SUBVERSION == 3
+#include "token_info-5.34.0.h"
 #elif PERL_VERSION == 34
 #include "token_info-5.34.0.h"
 #elif PERL_VERSION == 35 && PERL_SUBVERSION == 0
@@ -420,6 +424,10 @@
 #include "token_info-5.36.0.h"
 #elif PERL_VERSION == 36 && PERL_SUBVERSION == 1
 #include "token_info-5.36.0.h"
+#elif PERL_VERSION == 36 && PERL_SUBVERSION == 2
+#include "token_info-5.36.0.h"
+#elif PERL_VERSION == 36 && PERL_SUBVERSION == 3
+#include "token_info-5.36.0.h"
 #elif PERL_VERSION == 36
 #include "token_info-5.36.0.h"
 #elif PERL_VERSION == 37 && PERL_SUBVERSION == 0
@@ -448,7 +456,41 @@
 #include "token_info-5.37.10.h"
 #elif PERL_VERSION == 38 && PERL_SUBVERSION == 0
 #include "token_info-5.38.0.h"
-#elif PERL_VERSION > 38 || (PERL_VERSION == 38 && PERL_SUBVERSION > 0)
+#elif PERL_VERSION == 38 && PERL_SUBVERSION == 1
+#include "token_info-5.38.0.h"
+#elif PERL_VERSION == 38 && PERL_SUBVERSION == 2
+#include "token_info-5.38.0.h"
+#elif PERL_VERSION == 39 && PERL_SUBVERSION == 1
+#include "token_info-5.38.0.h"
+#elif PERL_VERSION == 39 && PERL_SUBVERSION == 2
+#include "token_info-5.38.0.h"
+#elif PERL_VERSION == 39 && PERL_SUBVERSION == 3
+#include "token_info-5.38.0.h"
+#elif PERL_VERSION == 39 && PERL_SUBVERSION == 4
+#include "token_info-5.38.0.h"
+#elif PERL_VERSION == 39 && PERL_SUBVERSION == 5
+#include "token_info-5.38.0.h"
+#elif PERL_VERSION == 39 && PERL_SUBVERSION == 6
+#include "token_info-5.38.0.h"
+#elif PERL_VERSION == 39 && PERL_SUBVERSION == 7
+#include "token_info-5.38.0.h"
+#elif PERL_VERSION == 39 && PERL_SUBVERSION == 8
+#include "token_info-5.38.0.h"
+#elif PERL_VERSION == 39 && PERL_SUBVERSION == 9
+#include "token_info-5.39.9.h"
+#elif PERL_VERSION == 39 && PERL_SUBVERSION == 10
+#include "token_info-5.39.9.h"
+#elif PERL_VERSION == 40 && PERL_SUBVERSION == 0
+#include "token_info-5.40.0.h"
+#elif PERL_VERSION == 41 && PERL_SUBVERSION == 1
+#include "token_info-5.40.0.h"
+#elif PERL_VERSION == 41 && PERL_SUBVERSION == 2
+#include "token_info-5.40.0.h"
+#elif PERL_VERSION == 41 && PERL_SUBVERSION == 3
+#include "token_info-5.41.3.h"
+#elif PERL_VERSION == 41 && PERL_SUBVERSION == 4
+#include "token_info-5.41.4.h"
+#elif PERL_VERSION > 41 || (PERL_VERSION == 41 && PERL_SUBVERSION > 4)
 #include "token_info-latest.h"
 #else
 #error "No support for this perl version"
